# Table of Contents

- [creating-fact-sheets](<./creating-fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Creating Fact Sheets](<./Creating-Fact-Sheets.md>)
  - [Introduction](<./Creating-Fact-Sheets/Introduction.md>)
  - [Creating a Fact Sheet in the Inventory](<./Creating-Fact-Sheets/Creating-a-Fact-Sheet-in-the-Inventory.md>)
  - [Fact Sheet Naming Convention](<./Creating-Fact-Sheets/Fact-Sheet-Naming-Convention.md>)
  - [Cloning a Fact Sheet](<./Creating-Fact-Sheets/Cloning-a-Fact-Sheet.md>)
  - [Was this page helpful?](<./Creating-Fact-Sheets/Was-this-page-helpful.md>)
